@@ -1,15 +1,26 @@
-CalGR <- function(PrepGR, CalCrit = c("NSE", "KGE", "KGE2", "RMSE"), 
+CalGR <- function(PrepGR, CalCrit = c("NSE", "KGE", "KGE2", "RMSE"),
                   WupPer = NULL, CalPer, transfo = c("", "sqrt", "log", "inv", "sort"), verbose = TRUE) {
-  
+
+  CalCrit <- match.arg(arg = CalCrit)
+  CalCrit <- sprintf("ErrorCrit_%s", CalCrit)
+  FUN_CRIT <- get(CalCrit)
+
+  if (! any(transfo %in% c("", "sqrt", "log", "inv", "sort"))) {
+    stop("Non convenient transformation \"transfo\"")
+  } else {
+    transfo <- transfo[1L]
+  }
+
+
   if (! any(class(PrepGR) %in% "PrepGR")) {
     stop("Non convenient data for argument \"PrepGR\". Must be of class \"PrepGR\"")
   }
-  
+
   isQobs <- !all(is.na(PrepGR$Qobs))
   if (!isQobs) {
     stop("\"PrepGR\" does not contain any Qobs values. It is not possible to calibrate the model")
   }
-  
+
   WupInd <- NULL
   if (!is.null(WupPer)) {
     WupPer <- as.POSIXct(WupPer, tz = "UTC")
@@ -26,7 +37,7 @@ CalGR <- function(PrepGR, CalCrit = c("NSE", "KGE", "KGE2", "RMSE"),
       }
     }
   }
-  
+
   CalPer <- as.POSIXct(CalPer, tz = "UTC")
   if (length(CalPer) != 2) {
     stop("Calibration period \"CalPer\" must be of length 2")
@@ -40,48 +51,36 @@ CalGR <- function(PrepGR, CalCrit = c("NSE", "KGE", "KGE2", "RMSE"),
       CalInd <- which(PrepGR$InputsModel$DatesR == CalPer[1]):which(PrepGR$InputsModel$DatesR == CalPer[2])
     }
   }
-  
-  if (! any(CalCrit %in% c("NSE", "KGE", "KGE2", "RMSE"))) {
-    stop("Non convenient efficiency criteria \"EffCrit\"")
-  } else {
-    CalCrit <- CalCrit[1L]
-    CalCrit <- sprintf("ErrorCrit_%s", CalCrit)
-    FUN_CRIT <- get(CalCrit)
-  }
-  
-  if (! any(transfo %in% c("", "sqrt", "log", "inv", "sort"))) {
-    stop("Non convenient transformation \"transfo\"")
-  } else {
-    transfo <- transfo[1L]
-  }
-  
-  MOD_opt <- CreateRunOptions(FUN_MOD = get(PrepGR$TypeModel), InputsModel = PrepGR$InputsModel, 
-                              IndPeriod_WarmUp = WupInd, IndPeriod_Run = CalInd, verbose = FALSE) 
-  
-  
-  MOD_crt <- CreateInputsCrit(FUN_CRIT = FUN_CRIT, InputsModel = PrepGR$InputsModel, 
+
+
+
+  MOD_opt <- CreateRunOptions(FUN_MOD = get(PrepGR$TypeModel), InputsModel = PrepGR$InputsModel,
+                              IndPeriod_WarmUp = WupInd, IndPeriod_Run = CalInd, verbose = FALSE)
+
+
+  MOD_crt <- CreateInputsCrit(FUN_CRIT = FUN_CRIT, InputsModel = PrepGR$InputsModel,
                               RunOptions = MOD_opt, Obs = PrepGR$Qobs[CalInd], transfo = transfo)
-  
-  
+
+
   CAL_opt <- CreateCalibOptions(FUN_MOD = get(PrepGR$TypeModel), FUN_CALIB = Calibration_Michel)
-  
-  
+
+
   CAL <- Calibration(InputsModel = PrepGR$InputsModel, RunOptions = MOD_opt,
                      InputsCrit = MOD_crt,  CalibOptions = CAL_opt,
                      FUN_MOD = get(PrepGR$TypeModel), FUN_CRIT = FUN_CRIT,
                      FUN_CALIB = Calibration_Michel, verbose = verbose)
-  
-  
+
+
   SIM <- RunModel(InputsModel = PrepGR$InputsModel, RunOptions = MOD_opt,
                   Param = CAL$ParamFinalR, FUN_MOD = get(PrepGR$TypeModel))
-  
-  
+
+
   CalGR <- list(OptionsCalib = MOD_opt, Qobs = PrepGR$Qobs[CalInd],
                 OutputsCalib = CAL, OutputsModel = SIM,
                 TypeModel = PrepGR$TypeModel, CalCrit = CalCrit,
                 PeriodModel = list(WarmUp = as.POSIXct(PrepGR$InputsModel$DatesR[range(MOD_opt$IndPeriod_WarmUp)], tz = "UTC"),
                                    Run    = CalPer))
   class(CalGR) <- c("CalGR", "GR", "airGRt")
-  return(CalGR)  
-  
-}
\ No newline at end of file
+  return(CalGR)
+
+}
